@@ -18,16 +18,18 @@
 #define GLOBUS_XIO_DRIVER_HTTP_H 1
 
 /**
- * @file globus_xio_http.h Globus XIO HTTP Driver Header
+ * @file globus_xio_http.h
+ * @brief Globus XIO HTTP Driver Header
  */
 #include "globus_xio.h"
 
-#ifndef GLOBUS_DONT_DOCUMENT_INTERNAL
-EXTERN_C_BEGIN
+#ifdef __cplusplus
+extern "C" {
 #endif
 
 /**
- * @defgroup http_driver Globus XIO HTTP Driver
+ * @defgroup globus_xio_http_driver Globus XIO HTTP Driver
+ * @ingroup globus_xio
  * This driver implements the HTTP/1.0 and HTTP/1.1 protocols within
  * the Globus XIO framework. It may be used with the tcp driver for
  * the standard HTTP protocol stack, or may be combined with the gsi
@@ -38,8 +40,8 @@ EXTERN_C_BEGIN
  */
 
 /**
- * @defgroup http_driver_instance Opening/Closing
- * @ingroup http_driver
+ * @defgroup globus_xio_http_driver_instance Opening/Closing
+ * @ingroup globus_xio_http_driver
  *
  * An XIO handle with the http driver can be created with either 
  * @ref globus_xio_handle_create() or
@@ -61,8 +63,8 @@ EXTERN_C_BEGIN
  */
 
 /**
- * @defgroup http_driver_io Reading/Writing
- * @ingroup http_driver
+ * @defgroup globus_xio_http_driver_io Reading/Writing
+ * @ingroup globus_xio_http_driver
  *
  * The HTTP driver behaves similar to the underlying transport driver
  * with respect to reads and writes with the exception that metadata must
@@ -72,8 +74,8 @@ EXTERN_C_BEGIN
  */
 
 /**
- * @defgroup http_driver_server Server
- * @ingroup http_driver
+ * @defgroup globus_xio_http_driver_server Server
+ * @ingroup globus_xio_http_driver
  *
  * The @ref globus_xio_server_create() causes a new transport-specific
  * listener socket to be created to handle new HTTP connections.
@@ -92,8 +94,8 @@ EXTERN_C_BEGIN
  */
 
 /**
- * @defgroup http_driver_cntls Attributes and Cntls
- * @ingroup http_driver
+ * @defgroup globus_xio_http_driver_cntls Attributes and Cntls
+ * @ingroup globus_xio_http_driver
  * 
  * HTTP driver specific attrs and cntls.
  * 
@@ -102,8 +104,8 @@ EXTERN_C_BEGIN
  */
 
 /**
- * @defgroup http_driver_errors Error Types
- * @ingroup http_driver
+ * @defgroup globus_xio_http_driver_errors Error Types
+ * @ingroup globus_xio_http_driver
  *
  * In addition to errors generated by underlying protocol drivers, the XIO
  * HTTP driver defines a few error conditions specific to the HTTP protocol.
@@ -120,8 +122,8 @@ EXTERN_C_BEGIN
  */
 
 /**
- * HTTP Header
- * @ingroup http_driver
+ * @brief HTTP Header
+ * @ingroup globus_xio_http_driver
  */
 typedef struct
 {
@@ -134,14 +136,14 @@ globus_xio_http_header_t;
 
 /**
  * HTTP driver specific cntls
- * @ingroup http_driver_cntls
+ * @ingroup globus_xio_http_driver_cntls
  */
 typedef enum
 {
     /**
      * GlobusVarArgEnum(handle)
      * Set the value of a response HTTP header. 
-     * @ingroup http_driver_cntls
+     * @ingroup globus_xio_http_driver_cntls
      *
      * @param header_name
      *        Name of the HTTP header to set.
@@ -181,7 +183,7 @@ typedef enum
     GLOBUS_XIO_HTTP_HANDLE_SET_RESPONSE_HEADER,
     /** GlobusVarArgEnum(handle)
      * Set the response status code.
-     * @ingroup http_driver_cntls
+     * @ingroup globus_xio_http_driver_cntls
      *
      * @param status
      * Value in the range 100-599 which will be used as the HTTP response
@@ -199,7 +201,7 @@ typedef enum
     GLOBUS_XIO_HTTP_HANDLE_SET_RESPONSE_STATUS_CODE,
     /** GlobusVarArgEnum(handle)
      * Set the response reason phrase.
-     * @ingroup http_driver_cntls
+     * @ingroup globus_xio_http_driver_cntls
      *
      * @param reason
      *        The value of the HTTP response string, as per RFC 2616.
@@ -217,7 +219,7 @@ typedef enum
     GLOBUS_XIO_HTTP_HANDLE_SET_RESPONSE_REASON_PHRASE,
     /** GlobusVarArgEnum(handle)
      * Set the response HTTP version.
-     * @ingroup http_driver_cntls
+     * @ingroup globus_xio_http_driver_cntls
      *
      * @param version
      *        The HTTP version to be used in the server response line.
@@ -237,7 +239,7 @@ typedef enum
     GLOBUS_XIO_HTTP_HANDLE_SET_RESPONSE_HTTP_VERSION,
     /** GlobusVarArgEnum(handle)
      * Indicate end-of-entity for an HTTP body.
-     * @ingroup http_driver_cntls
+     * @ingroup globus_xio_http_driver_cntls
      *
      * HTTP clients and servers must call this command to indicate to the
      * driver that the entity-body which is being sent is completed.
@@ -256,13 +258,13 @@ globus_xio_http_handle_cmd_t;
 
 /**
  * HTTP driver specific attribute and data descriptor cntls
- * @ingroup http_driver_cntls
+ * @ingroup globus_xio_http_driver_cntls
  */
 typedef enum
 {
     /** GlobusVarArgEnum(attr)
      * Set the HTTP method to use for a client request.
-     * @ingroup http_driver_cntls
+     * @ingroup globus_xio_http_driver_cntls
      *
      * @param method
      *        The request method string ("GET", "PUT", "POST", etc) that will
@@ -282,7 +284,7 @@ typedef enum
     GLOBUS_XIO_HTTP_ATTR_SET_REQUEST_METHOD,
     /** GlobusVarArgEnum(attr)
      * Set the HTTP version to use for a client request.
-     * @ingroup http_driver_cntls
+     * @ingroup globus_xio_http_driver_cntls
      *
      * @param version 
      * The HTTP version to use for the client request.
@@ -300,7 +302,7 @@ typedef enum
     GLOBUS_XIO_HTTP_ATTR_SET_REQUEST_HTTP_VERSION,
     /** GlobusVarArgEnum(attr)
      * Set the value of an HTTP request header. 
-     * @ingroup http_driver_cntls
+     * @ingroup globus_xio_http_driver_cntls
      *
      * @param header_name
      *        Name of the HTTP header to set.
@@ -412,7 +414,7 @@ globus_xio_http_attr_cmd_t;
 
 /**
  * Error types used to generate errors using the globus_error_generic module.
- * @ingroup http_driver_errors
+ * @ingroup globus_xio_http_driver_errors
  */
 typedef enum
 {
@@ -442,7 +444,7 @@ typedef enum
 globus_xio_http_errors_t;
 
 /**
- * @ingroup http_driver
+ * @ingroup globus_xio_http_driver
  * Valid HTTP versions, used with the
  * #GLOBUS_XIO_HTTP_ATTR_SET_REQUEST_HTTP_VERSION attribute and the
  * #GLOBUS_XIO_HTTP_HANDLE_SET_RESPONSE_HTTP_VERSION handle control
@@ -461,8 +463,8 @@ typedef enum
 }
 globus_xio_http_version_t;
 
-#ifndef GLOBUS_DONT_DOCUMENT_INTERNAL
-EXTERN_C_END
+#ifdef __cplusplus
+}
 #endif
 
 #endif
